GetRuntimeVersion

Trait GetRuntimeVersion 

pub trait GetRuntimeVersion<Block: BlockT> {
    // Required methods
    fn native_version(&self) -> &NativeVersion;
    fn runtime_version(
        &self,
        at: &BlockId<Block>,
    ) -> Result<RuntimeVersion, String>;
}
Something that can provide the runtime version at a given block and the native runtime version.

Required Methods

fn native_version(&self) -> &NativeVersion

Returns the version of the native runtime.

fn runtime_version(&self, at: &BlockId<Block>) -> Result<RuntimeVersion, String>

Returns the version of runtime at the given block.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T: GetRuntimeVersion<Block>, Block: BlockT> GetRuntimeVersion<Block> for Arc<T>

Available on crate feature std only.

Implementors