pub trait GetRuntimeVersion<Block: BlockT> {
// Required methods
fn native_version(&self) -> &NativeVersion;
fn runtime_version(
&self,
at: &BlockId<Block>,
) -> Result<RuntimeVersion, String>;
}Expand description
Something that can provide the runtime version at a given block and the native runtime version.
Required Methods
Sourcefn native_version(&self) -> &NativeVersion
fn native_version(&self) -> &NativeVersion
Returns the version of the native runtime.
Sourcefn runtime_version(&self, at: &BlockId<Block>) -> Result<RuntimeVersion, String>
fn runtime_version(&self, at: &BlockId<Block>) -> Result<RuntimeVersion, String>
Returns the version of runtime at the given block.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<T: GetRuntimeVersion<Block>, Block: BlockT> GetRuntimeVersion<Block> for Arc<T>
Available on crate feature std only.
impl<T: GetRuntimeVersion<Block>, Block: BlockT> GetRuntimeVersion<Block> for Arc<T>
Available on crate feature
std only.